@@ -3,7 +3,6 @@ import re
 import sys
 from typing import Dict
 from typing import Iterable
-from typing import List
 from typing import Optional
 from typing import Tuple
 
@@ -11,8 +10,10 @@ import matplotlib
 import matplotlib.pyplot as plt
 import numpy as np
 from colorspacious import cspace_converter
-from matplotlib.cm import register_cmap as register_cmap_mpl
+from matplotlib.axes import Axes
+from matplotlib.colors import Colormap
 from matplotlib.colors import LinearSegmentedColormap
+from matplotlib.figure import Figure
 from more_itertools import always_iterable
 
 # type aliases
@@ -25,7 +26,8 @@ else:
 
 _CMYT_PREFIX: Final[str] = "cmyt."
 PrimaryColorName = Literal["blue", "green", "red"]
-ColorDict = Dict[PrimaryColorName, List[Tuple[float, float, float]]]
+
+ColorDict = Dict[PrimaryColorName, Iterable[Tuple[float, float, float]]]
 
 # this is used in cmyt.cm to programmatically import all cmaps
 cmyt_cmaps = frozenset(
@@ -78,24 +80,37 @@ def unprefix_name(name: str) -> str:
     >>> unprefix_name("arbre")
     'arbre'
     """
-    if sys.version_info < (3, 9):
+    if sys.version_info >= (3, 9):
+        return name.removeprefix(_CMYT_PREFIX)
+    else:
         if name.startswith(_CMYT_PREFIX):
             return name[len(_CMYT_PREFIX) :]
         return name
-    return name.removeprefix(_CMYT_PREFIX)
+
+
+def _register_mpl_cmap(cmap: Colormap) -> None:
+    """
+    An adapter for matplotlib that works transparently with
+    either API (historical and post 3.5.0) while dodging deprecation
+    warnings.
+    """
+    if MPL_VERSION >= (3, 5, 0):
+        matplotlib.colormaps.register(cmap)
+    else:
+        matplotlib.cm.register_cmap(cmap=cmap)
 
 
 def register_colormap(
     name: str,
     color_dict: ColorDict,
-):
+) -> Tuple[LinearSegmentedColormap, LinearSegmentedColormap]:
     name = prefix_name(name)
 
     # register to MPL
     mpl_cmap = LinearSegmentedColormap(name=name, segmentdata=color_dict, N=256)
     mpl_cmap_r = mpl_cmap.reversed()
-    register_cmap_mpl(cmap=mpl_cmap)
-    register_cmap_mpl(cmap=mpl_cmap_r)
+    _register_mpl_cmap(mpl_cmap)
+    _register_mpl_cmap(mpl_cmap_r)
 
     # return cmaps with unprefixed names for registration as importable objects
     cmap = LinearSegmentedColormap(
@@ -111,19 +126,19 @@ _sRGB1_to_JCh = cspace_converter("sRGB1", graySCALE_CONVERSION_SPACE)
 _JCh_to_sRGB1 = cspace_converter(graySCALE_CONVERSION_SPACE, "sRGB1")
 
 
-def to_grayscale(sRGB1):
+def to_grayscale(sRGB1: np.ndarray) -> np.ndarray:
     # this is adapted from viscm 0.8
     JCh = _sRGB1_to_JCh(sRGB1)
     JCh[..., 1] = 0
     return np.clip(_JCh_to_sRGB1(JCh), 0, 1)
 
 
-def show_cmap(ax, rgb):
+def show_cmap(ax: Axes, rgb: np.ndarray) -> None:
     # this is adapted from viscm 0.8
     ax.imshow(rgb[np.newaxis, ...], aspect="auto")
 
 
-def get_rgb(cmap):
+def get_rgb(cmap: Colormap) -> np.ndarray:
     # this is adapted from viscm 0.8
     from matplotlib.colors import ListedColormap
 
@@ -140,7 +155,7 @@ def create_cmap_overview(
     subset: Optional[Iterable[str]] = None,
     filename: Optional[str] = None,
     with_grayscale: bool = False,
-):
+) -> Figure:
     # the name of this function is inspired from the cmasher library
     # but the actual content comes from yt
     """
